@@ -23,9 +23,13 @@
 #ifndef INCLUDE_LIBCHMFILEIMPL_H
 #define INCLUDE_LIBCHMFILEIMPL_H
 
-#include <sys/types.h>
+#if defined (USE_CHMLIB_WIN32)
+	#include "chmlib-win32/chm_lib.h"
+#else
+	#include "chm_lib.h"
+#endif
 
-#include "chm_lib.h"
+#include <sys/types.h>
 
 #include "libchmfile.h"
 #include "libchmtocimage.h"
@@ -38,11 +42,11 @@ class LCHMSearchProgressResult
 {
 	public:
 		inline LCHMSearchProgressResult() {}
-		inline LCHMSearchProgressResult( u_int32_t t, u_int32_t u ) : titleoff(t),urloff(u) {}
+		inline LCHMSearchProgressResult( unsigned int t, unsigned int u ) : titleoff(t),urloff(u) {}
 		
-		QVector<u_int64_t>		offsets;
-		u_int32_t				titleoff;
-		u_int32_t				urloff;
+		QVector<quint64>	offsets;
+		quint32				titleoff;
+		quint32				urloff;
 };
 
 //! An array to keeps the intermediate search results
@@ -144,15 +148,15 @@ class LCHMFileImpl
 		const char * GetFontEncFromCharSet (const QString& font) const;
 
 		//! Helper. Returns the $FIftiMain offset of leaf node or 0.
-		u_int32_t GetLeafNodeOffset(const QString& text,
-									u_int32_t initalOffset,
-		 							u_int32_t buffSize,
-   									u_int16_t treeDepth );
+		unsigned int GetLeafNodeOffset(const QString& text,
+									   unsigned int initialOffset,
+									   unsigned int buffSize,
+									   unsigned short treeDepth);
 
 		//! Helper. Processes the word location code entries while searching.
-		bool ProcessWLC(u_int64_t wlc_count, 
-						u_int64_t wlc_size,
-						u_int32_t wlc_offset,
+		bool ProcessWLC(quint64 wlc_count,
+						quint64 wlc_size,
+						quint32 wlc_offset,
 						unsigned char ds,
 						unsigned char dr, 
 						unsigned char cs,
