@@ -5,7 +5,7 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
+ *   the Free Software Foundation; either version 3 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
@@ -16,62 +16,52 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+
 #include "kde-qt.h"
 
 #include "libchmfile.h"
 
 #include "kchmcontentswindow.h"
-#include "kchmlistitemtooltip.h"
 #include "kchmmainwindow.h"
 #include "kchmtreeviewitem.h"
 
-#include "kchmcontentswindow.moc"
 
-KCHMContentsWindow::KCHMContentsWindow(QWidget *parent, const char *name)
-	: KQListView(parent, name)
+KCHMContentsWindow::KCHMContentsWindow( QWidget *parent )
+	: QWidget( parent ), Ui::TabContents()
 {
+	setupUi( this );
+	
 	m_contextMenu = 0;
+	m_contentFilled = false;
 	
-	addColumn( "Contents" ); // no i18n - this column is hidden
-	setSorting(-1);
-	setFocus();
-	setRootIsDecorated(true);
-	header()->hide();
-	setShowToolTips( false );
+	tree->setFocus();
+	tree->header()->hide();
 	
-	connect( this, SIGNAL( onItem ( QListViewItem * ) ), this, SLOT( slotOnItem( QListViewItem * ) ) );
-	connect( this, 
-			 SIGNAL( contextMenuRequested( QListViewItem *, const QPoint& , int ) ),
-			 this, 
-			 SLOT( slotContextMenuRequested ( QListViewItem *, const QPoint &, int ) ) );
-
+	// Handle clicking on m_contentsWindow element
+	connect( tree, 
+	         SIGNAL( itemClicked ( QTreeWidgetItem *, int ) ), 
+	         this, 
+	         SLOT( onClicked ( QTreeWidgetItem *, int ) ) );
 	
-	new KCHMListItemTooltip( this );
+	// Activate custom context menu, and connect it
+	tree->setContextMenuPolicy( Qt::CustomContextMenu );
+	connect( tree, 
+	         SIGNAL( customContextMenuRequested ( const QPoint & ) ),
+	         this, 
+	         SLOT( onContextMenuRequested( const QPoint & ) ) );
 }
 
 KCHMContentsWindow::~KCHMContentsWindow()
 {
 }
 
-void KCHMContentsWindow::slotContextMenuRequested( QListViewItem * item, const QPoint & point, int )
-{
-	if ( !m_contextMenu )
-		m_contextMenu = ::mainWindow->currentBrowser()->createListItemContextMenu( this );
-		
-	if( item )
-	{
-		KCHMIndTocItem * treeitem = (KCHMIndTocItem*) item;
-		::mainWindow->currentBrowser()->setTabKeeper( treeitem->getUrl() );
-		m_contextMenu->popup( point );
-	}
-}
-
 void KCHMContentsWindow::refillTableOfContents( )
 {
-	QValueVector< LCHMParsedEntry > data;
+	KCHMShowWaitCursor wc;
+	QVector< LCHMParsedEntry > data;
 	
 	if ( !::mainWindow->chmFile()->parseTableOfContents( &data )
 	|| data.size() == 0 )
@@ -80,9 +70,10 @@ void KCHMContentsWindow::refillTableOfContents( )
 		return;
 	}
 			   
-	kchmFillListViewWithParsedData( this, data, &m_urlListMap );
+	kchmFillListViewWithParsedData( tree, data, &m_urlListMap );
 }
 
+
 KCHMIndTocItem * KCHMContentsWindow::getTreeItem( const QString & url )
 {
 	QString fixedstr = ::mainWindow->chmFile()->normalizeUrl( url );
@@ -93,3 +84,54 @@ KCHMIndTocItem * KCHMContentsWindow::getTreeItem( const QString & url )
 		
 	return *it;
 }
+
+void KCHMContentsWindow::showItem(KCHMIndTocItem * item)
+{
+	tree->setCurrentItem( item );
+	tree->scrollToItem( item );
+}
+
+void KCHMContentsWindow::showEvent(QShowEvent *)
+{
+	if ( !::mainWindow->chmFile() || m_contentFilled )
+		return;
+	
+	m_contentFilled = true;
+	refillTableOfContents();
+}
+
+void KCHMContentsWindow::onClicked(QTreeWidgetItem * item, int)
+{
+	bool unused;
+	
+	if ( !item )
+		return;
+	
+	KCHMIndTocItem * treeitem = (KCHMIndTocItem*) item;
+	::mainWindow->activateLink( treeitem->getUrl(), unused );
+}
+
+void KCHMContentsWindow::onContextMenuRequested(const QPoint & point)
+{
+	KCHMIndTocItem * treeitem = (KCHMIndTocItem *) tree->itemAt( point );
+	
+	if( treeitem )
+	{
+		::mainWindow->currentBrowser()->setTabKeeper( treeitem->getUrl() );
+		::mainWindow->tabItemsContextMenu()->popup( tree->viewport()->mapToGlobal( point ) );
+	}
+}
+
+
+void KCHMContentsWindow::search( const QString & text )
+{
+	QList<QTreeWidgetItem*> items = tree->findItems( text, Qt::MatchWildcard | Qt::MatchRecursive );
+	bool unused;	
+	qDebug("found %d items of %d", items.size(), tree->
+			topLevelItemCount() );	
+	if ( items.isEmpty() )
+		return;
+			
+	KCHMIndTocItem * treeitem = (KCHMIndTocItem *) items.first();
+	::mainWindow->activateLink( treeitem->getUrl(), unused );
+}
