@@ -5,7 +5,7 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
+ *   the Free Software Foundation; either version 3 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
@@ -16,32 +16,30 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef KCHMDIALOGCHOOSEURLFROMLIST_H
 #define KCHMDIALOGCHOOSEURLFROMLIST_H
 
-#include <qdialog.h>
-#include <qlistview.h>
+#include <QDialog>
+#include "ui_dialog_topicselector.h"
 
-/**
-@author tim
-*/
-class KCHMDialogChooseUrlFromList : public QDialog
+
+class KCHMDialogChooseUrlFromList : public QDialog, public Ui::DialogTopicSelector
 {
-Q_OBJECT
-public:
-    KCHMDialogChooseUrlFromList (const QStringList& urls, const QStringList& titles, QWidget* parent);
-	QString getSelectedItemUrl()	{ return m_acceptedurl; }
+	Q_OBJECT
+	
+	public:
+    	KCHMDialogChooseUrlFromList( QWidget* parent );
+		
+		// Shows the dialog with titles, and let the user to select the title.
+		// Obviously urls.size() == titles.size(). Returns the appropriate URL
+		// for the selected title, or empty string if no title selected, or dialog canceled.
+		QString getSelectedItemUrl( const QStringList& urls, const QStringList& titles );
 
-private slots:
-	void onDoubleClicked( QListViewItem * item, const QPoint &, int );
-	void onCurrentChanged ( QListViewItem * item);
-
-private:
-	QListView *	m_urlsList;
-	QString		m_acceptedurl;
+	private slots:
+		void onDoubleClicked( QListWidgetItem * item );
 };
 
 #endif
