@@ -25,6 +25,7 @@
 
 #include "kde-qt.h"
 
+class KCHMViewWindowTabs;
 
 class KCHMViewWindow
 {
@@ -35,7 +36,7 @@ class KCHMViewWindow
 			SEARCH_WHOLEWORDS = 0x20
 		};
 	
-		KCHMViewWindow ( QTabWidget * parent );
+		KCHMViewWindow ( KCHMViewWindowTabs * parent );
 		virtual ~KCHMViewWindow();
 	
 		//! Open a page from current chm archive
@@ -118,6 +119,7 @@ class KCHMViewWindow
 		QMenu * 		getContextMenu( const QString& link, QWidget * parent );
 		QMenu * 		createStandardContextMenu( QWidget * parent );
 		
+	private:
 		//! History
 		class KCHMUrlHistory
 		{
@@ -140,17 +142,17 @@ class KCHMViewWindow
 		QMenu 				*	m_contextMenu;
 		QMenu 				*	m_contextMenuLink;
 		QList<KCHMUrlHistory>	m_history;
-			
-		// This member keeps a "open new tab" link between getContextMenu()
-		// call and appropriate slot call
-		QString					m_newTabLinkKeeper;
-		
+
 		QString 				m_openedPage;
 		QString 				m_lastOpenedPage;
 		QString					m_base_url;
 	
 		// The parent tab browser
-		QTabWidget			*	m_parentTabWidget;
+		KCHMViewWindowTabs	*	m_parentTabWidget;
+
+		// This member keeps a "open new tab" link between getContextMenu()
+		// call and appropriate slot call
+		QString					m_newTabLinkKeeper;
 };
 
 #endif
