@@ -29,7 +29,7 @@
 #include "kchmviewwindow_qtextbrowser.h"
 
 
-KCHMViewWindow_QTextBrowser::KCHMViewWindow_QTextBrowser( QTabWidget * parent )
+KCHMViewWindow_QTextBrowser::KCHMViewWindow_QTextBrowser( KCHMViewWindowTabs * parent )
 	: QTextBrowser ( parent ), KCHMViewWindow ( parent )
 {
 	m_zoomfactor = 0;
@@ -317,7 +317,7 @@ void KCHMViewWindow_QTextBrowser::contextMenuEvent(QContextMenuEvent * e)
 		m->addAction( i18n("Open Link in a new tab\tShift+LMB"), ::mainWindow, SLOT( onOpenPageInNewTab() ) );
 		m->addAction( i18n("Open Link in a new background tab\tCtrl+LMB"), ::mainWindow, SLOT( onOpenPageInNewBackgroundTab() ) );
 		m->addSeparator();
-		m_newTabLinkKeeper = link;
+		setTabKeeper( link );
 	}
 	
 	::mainWindow->setupPopupMenu( m );
@@ -325,3 +325,20 @@ void KCHMViewWindow_QTextBrowser::contextMenuEvent(QContextMenuEvent * e)
 	delete m;
 	
 }
+
+void KCHMViewWindow_QTextBrowser::mouseReleaseEvent ( QMouseEvent * event )
+{
+	if ( event->button() == Qt::MidButton )
+	{
+		QString link = anchorAt( event->pos() );
+
+		if ( !link.isEmpty() )
+		{
+			setTabKeeper( link );
+			::mainWindow->onOpenPageInNewBackgroundTab();
+			return;
+		}
+	}
+
+	QTextBrowser::mouseReleaseEvent( event );
+}
