@@ -31,7 +31,7 @@ class KCHMViewWindow_QTextBrowser : public QTextBrowser, public KCHMViewWindow
 {
 	Q_OBJECT
 	public:
-		KCHMViewWindow_QTextBrowser( QTabWidget * parent );
+		KCHMViewWindow_QTextBrowser( KCHMViewWindowTabs * parent );
 		~KCHMViewWindow_QTextBrowser();
 
 		//! Open a page from current chm archive
@@ -93,6 +93,8 @@ class KCHMViewWindow_QTextBrowser : public QTextBrowser, public KCHMViewWindow
 		// Overloaded to provide custom context menu
 		void 			contextMenuEvent( QContextMenuEvent *e );
 		
+		void			mouseReleaseEvent ( QMouseEvent * event );
+
 		void			find( bool forward, bool backward );
 		
 		QMenu * 		createPopupMenu ( const QPoint & pos );
