@@ -27,6 +27,7 @@
 #include "kde-qt.h"
 #include "kchmmainwindow.h"
 #include "kchmconfig.h"
+#include "kchmviewwindowmgr.h"
 #include "kchmviewwindow_khtmlpart.h"
 
 
@@ -35,7 +36,7 @@ QWidget * KCHMViewWindow_KHTMLPart::getQWidget()
 	 return view();
 }
 
-KCHMViewWindow_KHTMLPart::KCHMViewWindow_KHTMLPart( QTabWidget * parent )
+KCHMViewWindow_KHTMLPart::KCHMViewWindow_KHTMLPart( KCHMViewWindowTabs * parent )
 	: KHTMLPart ( parent ), KCHMViewWindow ( parent )
 {
 	m_zoomfactor = 0;
@@ -76,7 +77,7 @@ void KCHMViewWindow_KHTMLPart::setZoomFactor( int zoom )
 	m_zoomfactor = zoom;
 	
 	// Default ZoomFactor is 100, any increase or decrease should modify this value.
-	KHTMLPart::setZoomFactor ( 100 + (m_zoomfactor * 10) );
+	KHTMLPart::setFontScaleFactor ( 100 + (m_zoomfactor * 10) );
 }
 
 void KCHMViewWindow_KHTMLPart::invalidate( )
